@@ -2,7 +2,7 @@ from django import template
 
 from ..helpers import get_content_id
 from ..settings import TORRENT_STREAM_PLAYER
-from ..exceptions import ServerFault
+from ..exceptions import FailedResponse, ServerFault
 
 register = template.Library()
 
@@ -15,7 +15,7 @@ def receive_content_id(torrent_file):
         content = torrent_file.read()
     try:
         return get_content_id(content)
-    except ServerFault:
+    except (FailedResponse, ServerFault):
         return None
 
 
